IntegerBounds

Struct IntegerBounds 

pub struct IntegerBounds {
    pub position: Vec2<i32>,
    pub size: Vec2<usize>,
}
A rectangular section anywhere in 2D integer space. Valid from minimum coordinate (including) -1,073,741,822 to maximum coordinate (including) 1,073,741,822, the value of (i32::MAX/2 -1).

Fields

position: Vec2<i32>

The top left corner of this rectangle. The Box2I32 includes this pixel if the size is not zero.

size: Vec2<usize>

How many pixels to include in this Box2I32. Extends to the right and downwards. Does not include the actual boundary, just like Vec::len().

Implementations

Source

impl IntegerBounds

pub fn zero() -> Self

Create a box with no size located at (0,0).

pub fn from_dimensions(size: impl Into<Vec2<usize>>) -> Self

Create a box with a size starting at zero.

pub fn new(start: impl Into<Vec2<i32>>, size: impl Into<Vec2<usize>>) -> Self

Create a box with a size and an origin point.

pub fn end(self) -> Vec2<i32>

Returns the top-right coordinate of the rectangle. The row and column described by this vector are not included in the rectangle, just like Vec::len().

pub fn max(self) -> Vec2<i32>

Returns the maximum coordinate that a value in this rectangle may have.

pub fn validate(&self, max_size: Option<Vec2<usize>>) -> UnitResult

Validate this instance.

pub fn byte_size() -> usize

Number of bytes this would consume in an exr file.

pub fn write<W: Write>(&self, write: &mut W) -> UnitResult

Without validation, write this instance to the byte stream.

pub fn read<R: Read>(read: &mut R) -> Result<Self>

Read the value without validating.

pub fn with_origin(self, origin: Vec2<i32>) -> Self

Create a new rectangle which is offset by the specified origin.

pub fn contains(self, subset: Self) -> bool

Returns whether the specified rectangle is equal to or inside this rectangle.